@@ -122,7 +122,7 @@ module Net
           user = proxy_user
           passwd = proxy_password
 
-          packet = [ SOCKS_VERSION,
+          packet = [ 0x01,
                      user.length, user,
                      passwd.length, passwd ].pack( "CCA*CA*" )
 
