@@ -127,8 +127,8 @@ module Net
           # server. This is where the command to execute will be sent to the
           # server.
           def do_confirm( channel )
-            channel.on_success &method(:do_exec_success)
-            channel.on_failure &method(:do_exec_failure)
+            channel.on_success(&method(:do_exec_success))
+            channel.on_failure(&method(:do_exec_failure))
             channel.exec @command, true
           end
 
@@ -136,10 +136,10 @@ module Net
           # This registers various callbacks, and then calls the +on_success+
           # callback (if registered).
           def do_exec_success( channel )
-            channel.on_data &method(:do_data)
-            channel.on_extended_data &method(:do_extended_data)
-            channel.on_close &method(:do_close)
-            channel.on_request &method(:do_request)
+            channel.on_data(&method(:do_data))
+            channel.on_extended_data(&method(:do_extended_data))
+            channel.on_close(&method(:do_close))
+            channel.on_request(&method(:do_request))
             @on_success.call( self ) if @on_success
           end
 
