@@ -34,12 +34,14 @@ module Net
           ns.require "net/ssh/service/forward/services", "#{self}::Forward"
           ns.require "net/ssh/service/process/services", "#{self}::Process"
           ns.require "net/ssh/service/shell/services", "#{self}::Shell"
+          ns.require "net/ssh/service/agentforward/services", "#{self}::AgentForward"
         end
 
         # Add the services to the services hash.
         container.services[ :forward ] = container.service.forward.driver
         container.services[ :process ] = container.service.process.driver
         container.services[ :shell ] = container.service.shell.driver
+        container.services[ :agentforward ] = container.service.agentforward.driver
 
         # Register the external services and add them to the collection of
         # known services.
