@@ -16,6 +16,7 @@
 
 require 'net/ssh/errors'
 require 'net/ssh/transport/constants'
+require 'net/ssh/known-hosts'
 
 module Net
   module SSH
@@ -68,9 +69,16 @@ module Net
 
         # Builds the @algorithms hash from the values specified in the
         # +options+ hash.
-        def prepare_preferred_algorithms( options )
+        def prepare_preferred_algorithms( session, options )
           @algorithms = Hash.new
 
+          if !options.key?(:host_key)
+            keys = Net::SSH::KnownHosts.search_for(Net::SSH::KnownHosts.canonize(session.host, session.port))
+            preferred_order = []
+            preferred_order << keys.first.ssh_type if keys.any?
+            options = options.merge(:host_key => preferred_order)
+          end
+
           prepare_preferred_algorithm options, :host_key
           prepare_preferred_algorithm options, :kex
           prepare_preferred_algorithm options, :encryption
@@ -99,7 +107,7 @@ module Net
         # cannot be reached between what the client wants and what the server
         # can provide, this will fail.
         def negotiate( session, options )
-          prepare_preferred_algorithms options
+          prepare_preferred_algorithms session, options
 
           # first, discover what the server can do
           type, buffer = session.wait_for_message
