@@ -170,7 +170,7 @@ module Net
             # then validate it.
             hmac = @hmac.mac_length > 0 ? read( @hmac.mac_length ) : ""
 
-            reader.append @cipher.update( data )
+            reader.append @cipher.update( data ) unless data.empty?
             reader.append @cipher.final
 
             padding_length = reader.read_byte
