@@ -1,6 +1,6 @@
 #--
 # =============================================================================
-# Copyright (c) 2004,2005 Jamis Buck (jamis_buck@byu.edu)
+# Copyright (c) 2004,2005 Jamis Buck (jamis@37signals.com)
 # All rights reserved.
 #
 # This source file is distributed as part of the Net::SSH Secure Shell Client
@@ -14,8 +14,5 @@
 # =============================================================================
 #++
 
-$:.unshift "../lib"
-
 $run_integration_tests = ARGV.include?( "-i" )
-
-Dir["**/tc_*.rb"].each { |f| load f }
+Dir["#{File.dirname(__FILE__)}/**/tc_*.rb"].each { |f| load f }
