@@ -19,6 +19,7 @@ $:.unshift "#{File.dirname(__FILE__)}/../../lib"
 if $run_integration_tests || __FILE__ == $0
 
   require 'needle'
+  require 'net/ssh/null-host-key-verifier'
   require 'net/ssh/connection/services'
   require 'net/ssh/transport/services'
   require 'net/ssh/userauth/services'
@@ -43,6 +44,7 @@ if $run_integration_tests || __FILE__ == $0
       @registry.define do |b|
         b.crypto_backend { :ossl }
         b.transport_host { HOST }
+        b.host_key_verifier { Net::SSH::NullHostKeyVerifier.new }
       end
 
       @registry[:userauth][:driver].authenticate SERVICE, USER, PASSWORD
@@ -59,10 +61,10 @@ if $run_integration_tests || __FILE__ == $0
       exec_data = ""
       @connection.open_channel "session" do |chan|
         chan.on_data { |ch,data| exec_data << data }
-        chan.exec "echo $HOME"
+        chan.exec "echo hello"
       end
       @connection.loop
-      assert_equal "/home/test\n", exec_data
+      assert_equal "hello\n", exec_data
     end
 
     def test_dialog
