@@ -126,7 +126,7 @@ class TC_Forward_Driver < Test::Unit::TestCase
       assert_equal 0, @driver.open_direct_channel_count
       assert @driver.active_locals.empty?
 
-      @driver.local *args
+      @driver.local(*args)
 
       address = '127.0.0.1'
       address = args.shift if args.first.is_a? String
