@@ -19,6 +19,7 @@ $:.unshift "#{File.dirname(__FILE__)}/../../lib"
 if $run_integration_tests || __FILE__ == $0
 
   require 'needle'
+  require 'net/ssh/null-host-key-verifier'
   require 'net/ssh/transport/services'
   require 'net/ssh/userauth/services'
   require 'test/unit'
@@ -41,6 +42,7 @@ if $run_integration_tests || __FILE__ == $0
       @registry.define do |b|
         b.crypto_backend { :ossl }
         b.transport_host { HOST }
+        b.host_key_verifier { Net::SSH::NullHostKeyVerifier.new }
       end
 
       @userauth = @registry[:userauth][:driver]
